.. sjkabc documentation master file, created by
   sphinx-quickstart on Fri Mar  4 16:43:18 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sjkabc's documentation!
==================================

sjkabc is a Python 3 library that provides ABC music notation parsing functionality.

Thanks to
---------

* `Dr Bryan Duggan`_ - for his thesis on 'Machine annotation of traditional Irish dance music' and for creating `Tunepal`_
* `Peter van Dijk`_ - for help and advice on Python related issues

.. _Dr Bryan Duggan: http://bryanduggan.org
.. _Peter van Dijk: http://7bits.nl
.. _Tunepal: http://tunepal.org

Contents:

.. toctree::
   :maxdepth: 2

   tutorial
   sjkabc
   limitations
   contributing
   changelog
